@@ -1,13 +1,12 @@
 __title__ = 'qq'
 __author__ = 'Foxwhite'
 __license__ = 'MIT'
-__version__ = '0.1.2'
+__version__ = '0.1.4'
 
 __path__ = __import__('pkgutil').extend_path(__path__, __name__)
 
 import logging
 from typing import NamedTuple
-
 from .client import *
 from .user import *
 from .channel import *
@@ -24,6 +23,9 @@ from . import utils, abc
 from .enum import *
 from .shard import *
 from .error import *
+from .embeds import *
+from .mention import *
+
 
 class VersionInfo(NamedTuple):
     major: int
@@ -33,6 +35,4 @@ class VersionInfo(NamedTuple):
     serial: int
 
 
-version_info: VersionInfo = VersionInfo(major=0, minor=1, micro=2, releaselevel='alpha', serial=0)
-
-logging.getLogger(__name__).addHandler(logging.NullHandler())
+version_info: VersionInfo = VersionInfo(major=0, minor=1, micro=4, releaselevel='alpha', serial=0)
