@@ -14,7 +14,7 @@ from . import __version__, utils, role
 from .error import HTTPException, Forbidden, NotFound, QQServerError, LoginFailure, GatewayNotFound
 from .gateway import QQClientWebSocketResponse
 from .types.message import Message
-from .types import user, guild, message
+from .types import user, guild, message, channel, member
 from .types.embed import Embed
 from .utils import MISSING
 from .types.channel import Channel as ChannelPayload
@@ -163,14 +163,14 @@ class HTTPClient:
                     kwargs['data'] = form_data
                 try:
                     async with self.__session.request(method, url, **kwargs) as response:
-                        _log.debug('%s %s with %s has returned %s', method, url, kwargs.get('data'), response.status)
+                        _log.debug('%s %s 与 %s 已返回 %s', method, url, kwargs.get('data'), response.status)
 
                         # even errors have text involved in them so this is safe to call
                         data = await json_or_text(response)
 
                         # the request was successful so just return the text/json
                         if 300 > response.status >= 200:
-                            _log.debug('%s %s has received %s', method, url, data)
+                            _log.debug('%s %s 已收到 %s', method, url, data)
                             return data
 
                         # we've received a 500, 502, or 504, unconditional retry
@@ -203,7 +203,7 @@ class HTTPClient:
 
                     raise HTTPException(response, data)
 
-                raise RuntimeError('Unreachable code in HTTP handling')
+                raise RuntimeError('HTTP 处理中无法访问的代码')
 
     async def static_login(self, token: str) -> user.User:
         # Necessary to get aiohttp to stop complaining about session creation
@@ -216,7 +216,7 @@ class HTTPClient:
         except HTTPException as exc:
             self.token = old_token
             if exc.status == 401:
-                raise LoginFailure('Improper token has been passed.') from exc
+                raise LoginFailure('传递了不正确的令牌。') from exc
             raise
 
         return data
@@ -301,7 +301,7 @@ class HTTPClient:
         return self.request(r, reason=reason)
 
     def remove_role(
-            self, guild_id: str, user_id: str, role_id: str, *, reason: Optional[str] = None
+            self, guild_id: int, user_id: int, role_id: int, *, reason: Optional[str] = None
     ) -> Response[None]:
         r = Route(
             'DELETE',
@@ -312,6 +312,73 @@ class HTTPClient:
         )
         return self.request(r, reason=reason)
 
+    def create_channel(
+            self,
+            guild_id: int,
+            channel_type: channel.ChannelType,
+            *,
+            reason: Optional[str] = None,
+            **options: Any,
+    ) -> Response[channel.GuildChannel]:
+        payload = {
+            'type': channel_type,
+        }
+
+        valid_keys = (
+            'name',
+            'parent_id',
+            'position',
+        )
+        payload.update({k: v for k, v in options.items() if k in valid_keys and v is not None})
+
+        return self.request(Route('POST', '/guilds/{guild_id}/channels', guild_id=guild_id), json=payload,
+                            reason=reason)
+
+    def edit_channel(
+            self,
+            channel_id: int,
+            *,
+            reason: Optional[str] = None,
+            **options: Any,
+    ) -> Response[channel.Channel]:
+        r = Route('PATCH', '/channels/{channel_id}', channel_id=channel_id)
+        valid_keys = (
+            'name',
+            'parent_id',
+            'position',
+            'type',
+        )
+        payload = {k: v for k, v in options.items() if k in valid_keys}
+        return self.request(r, reason=reason, json=payload)
+
+    def bulk_channel_update(
+        self,
+        guild_id: int,
+        datas: List[guild.ChannelPositionUpdate],
+        *,
+        reason: Optional[str] = None,
+    ) -> List[Response[None]]:
+        rsp = []
+        for data in datas:
+            valid_keys = (
+                'name',
+                'parent_id',
+                'position',
+                'type',
+            )
+            payload = {k: v for k, v in data.items() if k in valid_keys}
+            r = Route('PATCH', '/channels/{channel_id}', channel_id=data.get('id'))
+            rsp.append(self.request(r, reason=reason, json=payload))
+        return rsp
+
+    def delete_channel(
+            self,
+            channel_id: int,
+            *,
+            reason: Optional[str] = None,
+    ) -> Response[None]:
+        return self.request(Route('DELETE', '/channels/{channel_id}', channel_id=channel_id), reason=reason)
+
     async def get_from_cdn(self, url: str) -> bytes:
         async with self.__session.get(url) as resp:
             if resp.status == 200:
@@ -371,12 +438,9 @@ class HTTPClient:
             self,
             channel_id: int,
             content: Optional[str],
+            image_url: Optional[str],
             *,
             tts: bool = False,
-            embed: Optional[Embed] = None,
-            embeds: Optional[List[Embed]] = None,
-            nonce: Optional[str] = None,
-            allowed_mentions: Optional[message.AllowedMentions] = None,
             message_reference: Optional[message.MessageReference] = None,
     ) -> Response[message.Message]:
         r = Route('POST', '/channels/{channel_id}/messages', channel_id=channel_id)
@@ -388,14 +452,28 @@ class HTTPClient:
         if tts:
             payload['tts'] = True
 
-        if embed:
-            payload['embeds'] = [embed]
-
-        if embeds:
-            payload['embeds'] = embeds
-
         if message_reference:
             payload['msg_id'] = message_reference['message_id']
 
+        payload['image'] = image_url
+
         return self.request(r, json=payload)
 
+    def get_all_guild_channels(self, guild_id: int) -> Response[List[guild.GuildChannel]]:
+        return self.request(Route('GET', '/guilds/{guild_id}/channels', guild_id=guild_id))
+
+    def get_member(self, guild_id: int, member_id: int) -> Response[member.MemberWithUser]:
+        return self.request(
+            Route('GET', '/guilds/{guild_id}/members/{member_id}', guild_id=guild_id, member_id=member_id))
+
+    def get_channel(self, channel_id: int) -> Response[channel.Channel]:
+        r = Route('GET', '/channels/{channel_id}', channel_id=channel_id)
+        return self.request(r)
+
+    def kick(self, user_id: int, guild_id: int, reason: Optional[str] = None) -> Response[None]:
+        r = Route('DELETE', '/guilds/{guild_id}/members/{user_id}', guild_id=guild_id, user_id=user_id)
+        if reason:
+            # thanks aiohttp
+            r.url = f'{r.url}?reason={_uriquote(reason)}'
+
+        return self.request(r)
